Prolog
======

Django-security-logger is library for logging input and output request. Library can be used with django-reversion to log which data was changed in a request.
The library provides throttling security mechanism.

Installation
------------

.. code:: bash

    pip install django-security-logger


Docs
----

For more details see [docs](http://django-security-logger.readthedocs.org/)
